package com.example.shawarma.screens.orders

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material.Button
import androidx.compose.material.ButtonDefaults
import androidx.compose.material.Card
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.zIndex
import com.example.shawarma.models.OrderModel
import com.example.shawarma.models.OrderStatus
import com.example.shawarma.models.getAllOrders
import com.example.shawarma.ui.theme.MarckFamily
import com.example.shawarma.ui.theme.MyLightYellow
import com.example.shawarma.ui.theme.MyMainBackground
import com.example.shawarma.ui.theme.MyOrange
import com.example.shawarma.ui.theme.NunitoFamily
import com.example.shawarma.widgets.ShawarmaLogo2
import java.text.SimpleDateFormat

@Composable
fun OrdersScreen() {
    Box(
        contentAlignment = Alignment.Center
    ) {
        ShawarmaLogo2()
        OrdersList()
    }
}

@Composable
fun OrdersList(){

    val allOrders = getAllOrders()
    val preparingOrders = mutableListOf<OrderModel>()
    val preparedOrders = mutableListOf<OrderModel>()
    val processedOrders = mutableListOf<OrderModel>()

    for (order in allOrders){
        if (order.status == OrderStatus.Preparing) {
            preparingOrders.add(order)
        }
        if (order.status == OrderStatus.Prepared) {
            preparedOrders.add(order)
        }
        if (order.status == OrderStatus.Processed) {
            processedOrders.add(order)
        }
    }


    Box(
        modifier = Modifier
            .clip(shape = RoundedCornerShape(30.dp))
            .padding(top = 100.dp)
            .fillMaxSize()
            .background(color = MyMainBackground)
            .zIndex(2f),

        contentAlignment = Alignment.TopCenter
    ) {
        Text(
            text = "Заказы",
            fontFamily = MarckFamily,
            fontSize = 40.sp,
            modifier = Modifier.padding(top = 15.dp)
        )

        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 55.dp)
                .verticalScroll(rememberScrollState())
        ){
            Text(
                text = "Готовится:",
                fontFamily = NunitoFamily,
                fontSize = 20.sp,
                modifier = Modifier.padding(top = 15.dp),
                fontWeight = FontWeight.Bold
            )
            LazyColumn(
                modifier = Modifier
                    .width(340.dp)
                    .height(250.dp)
            ) {
                items(preparingOrders.size) {
                    index ->
                    PreparingItem(preparedOrders[index])
                }
            }
            Text(
                text = "Готово:",
                fontFamily = NunitoFamily,
                fontSize = 20.sp,
                modifier = Modifier.padding(top = 15.dp),
                fontWeight = FontWeight.Bold
            )
            LazyColumn(
                modifier = Modifier
                    .width(340.dp)
                    .height(250.dp)
            ) {
                items(preparedOrders.size) {
                    index ->
                    PreparedItem(preparedOrders[index])
                }
            }
            Text(
                text = "Выдано:",
                fontFamily = NunitoFamily,
                fontSize = 20.sp,
                modifier = Modifier.padding(top = 15.dp),
                fontWeight = FontWeight.Bold
            )
            LazyColumn(
                modifier = Modifier
                    .width(340.dp)
                    .height(250.dp)
            ) {
                items(2) {
                    ProcessedItem()
                }
            }
            Spacer(modifier = Modifier.height(70.dp))
        }


    }
}

@Composable
fun PreparingItem(order : OrderModel){
    Card(
        border = BorderStroke(width = 2.dp, color = MyOrange),
        shape = RoundedCornerShape(size = 20.dp),
        backgroundColor = Color.White,
        modifier = Modifier.size(340.dp, 100.dp)
    ){
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceBetween,
            modifier = Modifier.padding(20.dp)
        ){
            Column(

                modifier = Modifier.fillMaxWidth(0.5f)
            ){
                val localDateFormat = SimpleDateFormat("HH:mm")
                val time = localDateFormat.format(order.date)
                Text(
                    text = time,
                    fontFamily = NunitoFamily,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold
                )
                Row(
                    horizontalArrangement = Arrangement.SpaceBetween,
                    modifier = Modifier.fillMaxWidth()
                ){
                    Text(
                        text = "Классика",
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                    Text(
                        text = "x" + order.productsId.values.first().toString(),
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                }
            }


            Button(
                colors = ButtonDefaults.buttonColors(
                    backgroundColor = MyLightYellow
                ),
                shape = RoundedCornerShape(size = 10.dp),
                modifier = Modifier
                    .size(100.dp, 60.dp)
                    .fillMaxSize(0.5f),
                onClick = { /*TODO*/ }
            ) {
                Text(
                    text = "Готово!",
                    fontFamily = NunitoFamily,
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
            }
        }
    }

    Spacer(modifier = Modifier.height(20.dp))
}

@Composable
fun PreparedItem(order : OrderModel){
    Card(
        border = BorderStroke(width = 2.dp, color = MyOrange),
        shape = RoundedCornerShape(size = 20.dp),
        backgroundColor = Color.White,
        modifier = Modifier.size(340.dp, 100.dp)
    ){
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceBetween,
            modifier = Modifier.padding(20.dp)
        ){
            Column(

                modifier = Modifier.fillMaxWidth(0.5f)
            ){
                val localDateFormat = SimpleDateFormat("HH:mm")
                val time = localDateFormat.format(order.date)
                Text(
                    text = time,
                    fontFamily = NunitoFamily,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold
                )
                Row(
                    horizontalArrangement = Arrangement.SpaceBetween,
                    modifier = Modifier.fillMaxWidth()
                ){
                    Text(
                        text = "Классика",
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                    Text(
                        text = "x" + order.productsId.values.first().toString(),
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                }
            }


            Button(
                colors = ButtonDefaults.buttonColors(
                    backgroundColor = MyLightYellow
                ),
                shape = RoundedCornerShape(size = 10.dp),
                modifier = Modifier
                    .size(100.dp, 60.dp)
                    .fillMaxSize(0.5f),
                onClick = { /*TODO*/ }
            ) {
                Text(
                    text = "Выдано!",
                    fontFamily = NunitoFamily,
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
            }
        }
    }

    Spacer(modifier = Modifier.height(20.dp))
}

@Composable
fun ProcessedItem(){
    Card(
        border = BorderStroke(width = 2.dp, color = MyOrange),
        shape = RoundedCornerShape(size = 20.dp),
        backgroundColor = Color.White,
        modifier = Modifier.size(340.dp, 100.dp)
    ){
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceBetween,
            modifier = Modifier.padding(20.dp)
        ){
            Column(

                modifier = Modifier.fillMaxWidth(0.5f)
            ){
                Text(
                    text = "16:24",
                    fontFamily = NunitoFamily,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold
                )
                Row(
                    horizontalArrangement = Arrangement.SpaceBetween,
                    modifier = Modifier.fillMaxWidth()
                ){
                    Text(
                        text = "Классика",
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                    Text(
                        text = "x2",
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                }
            }


            Column(

                modifier = Modifier.fillMaxWidth(0.5f)
            ){
                Text(
                    text = "300 руб.",
                    fontFamily = NunitoFamily,
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
                Text(
                    text = "20.03.2012",
                    fontFamily = NunitoFamily,
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
            }
        }
    }

    Spacer(modifier = Modifier.height(20.dp))
}